@@ -21,12 +21,12 @@
 *  You should have received a copy of the GNU General Public License        *
 *  along with this program; if not, write to the Free Software              *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
- *****************************************************************************/ 
+ *****************************************************************************/
 
 #ifndef CALLS_H
 #define CALLS_H
 //#include <klocale.h>
-#include <qstring.h>
+#include <QString>
 
  #define CALL_LENGTH 15
 // This class is to know if we have previously worked a call
